# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/mail/mail.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/mail/mail.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ayeying/api/mail/mail.proto\x12\x0fyeying.api.mail\x1a\x1fyeying/api/common/message.proto"w\n\x0fSendMailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.mail.SendMailRequestBody"%\n\x13SendMailRequestBody\x12\x0e\n\x06toMail\x18\x01 \x01(\t"y\n\x10SendMailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.mail.SendMailResponseBody"I\n\x14SendMailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"{\n\x11VerifyMailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.mail.VerifyMailRequestBody"5\n\x15VerifyMailRequestBody\x12\x0e\n\x06toMail\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t"}\n\x12VerifyMailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.mail.VerifyMailResponseBody"K\n\x16VerifyMailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xaa\x01\n\x04Mail\x12M\n\x04Send\x12 .yeying.api.mail.SendMailRequest\x1a!.yeying.api.mail.SendMailResponse"\x00\x12S\n\x06Verify\x12".yeying.api.mail.VerifyMailRequest\x1a#.yeying.api.mail.VerifyMailResponse"\x00\x42\x11Z\x0fyeying/api/mailb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.mail.mail_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\017yeying/api/mail"
    _globals["_SENDMAILREQUEST"]._serialized_start = 80
    _globals["_SENDMAILREQUEST"]._serialized_end = 199
    _globals["_SENDMAILREQUESTBODY"]._serialized_start = 201
    _globals["_SENDMAILREQUESTBODY"]._serialized_end = 238
    _globals["_SENDMAILRESPONSE"]._serialized_start = 240
    _globals["_SENDMAILRESPONSE"]._serialized_end = 361
    _globals["_SENDMAILRESPONSEBODY"]._serialized_start = 363
    _globals["_SENDMAILRESPONSEBODY"]._serialized_end = 436
    _globals["_VERIFYMAILREQUEST"]._serialized_start = 438
    _globals["_VERIFYMAILREQUEST"]._serialized_end = 561
    _globals["_VERIFYMAILREQUESTBODY"]._serialized_start = 563
    _globals["_VERIFYMAILREQUESTBODY"]._serialized_end = 616
    _globals["_VERIFYMAILRESPONSE"]._serialized_start = 618
    _globals["_VERIFYMAILRESPONSE"]._serialized_end = 743
    _globals["_VERIFYMAILRESPONSEBODY"]._serialized_start = 745
    _globals["_VERIFYMAILRESPONSEBODY"]._serialized_end = 820
    _globals["_MAIL"]._serialized_start = 823
    _globals["_MAIL"]._serialized_end = 993
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/task/task.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/task/task.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ayeying/api/task/task.proto\x12\x0fyeying.api.task\x1a\x1fyeying/api/common/message.proto"\x13\n\x11\x43reateTaskRequest"\x14\n\x12\x43reateTaskResponse"\xa6\x01\n\x0cTaskMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12+\n\x04\x63ode\x18\x02 \x01(\x0e\x32\x1d.yeying.api.task.TaskCodeEnum\x12\x0f\n\x07\x63reator\x18\x03 \x01(\t\x12\x13\n\x0bparticipant\x18\x04 \x01(\t\x12\x12\n\nterminator\x18\x05 \x01(\t\x12\x11\n\tcreatedAt\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t"A\n\x11\x46\x65tchTaskResponse\x12,\n\x05tasks\x18\x01 \x03(\x0b\x32\x1d.yeying.api.task.TaskMetadata*>\n\x0cTaskCodeEnum\x12\x15\n\x11TASK_CODE_UNKNOWN\x10\x00\x12\x17\n\x13TASK_CODE_STATISTIC\x10\x01\x32[\n\x04Task\x12S\n\x06\x43reate\x12".yeying.api.task.CreateTaskRequest\x1a#.yeying.api.task.CreateTaskResponse"\x00\x42\x11Z\x0fyeying/api/taskb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.task.task_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\017yeying/api/task"
    _globals["_TASKCODEENUM"]._serialized_start = 359
    _globals["_TASKCODEENUM"]._serialized_end = 421
    _globals["_CREATETASKREQUEST"]._serialized_start = 80
    _globals["_CREATETASKREQUEST"]._serialized_end = 99
    _globals["_CREATETASKRESPONSE"]._serialized_start = 101
    _globals["_CREATETASKRESPONSE"]._serialized_end = 121
    _globals["_TASKMETADATA"]._serialized_start = 124
    _globals["_TASKMETADATA"]._serialized_end = 290
    _globals["_FETCHTASKRESPONSE"]._serialized_start = 292
    _globals["_FETCHTASKRESPONSE"]._serialized_end = 357
    _globals["_TASK"]._serialized_start = 423
    _globals["_TASK"]._serialized_end = 514
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/support/support.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/support/support.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n yeying/api/support/support.proto\x12\x12yeying.api.support\x1a\x1fyeying/api/common/message.proto"\x86\x01\n\x15\x43ollectSupportRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.support.CollectSupportRequestBody"\x86\x01\n\x19\x43ollectSupportRequestBody\x12\x31\n\x04\x63ode\x18\x01 \x01(\x0e\x32#.yeying.api.support.SupportCodeEnum\x12.\n\x03\x66\x61q\x18\x03 \x01(\x0b\x32\x1f.yeying.api.support.FaqMetadataH\x00\x42\x06\n\x04\x64\x61ta"r\n\x0b\x46\x61qMetadata\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tcreatedAt\x18\x05 \x01(\t\x12\x11\n\tsignature\x18\x06 \x01(\t"\x88\x01\n\x16\x43ollectSupportResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12<\n\x04\x62ody\x18\x02 \x01(\x0b\x32..yeying.api.support.CollectSupportResponseBody"O\n\x1a\x43ollectSupportResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus*S\n\x0fSupportCodeEnum\x12\x14\n\x10SUPPORT_CODE_FAQ\x10\x00\x12\x14\n\x10SUPPORT_CODE_CSR\x10\x01\x12\x14\n\x10SUPPORT_CODE_IVR\x10\x02\x32m\n\x07Support\x12\x62\n\x07\x43ollect\x12).yeying.api.support.CollectSupportRequest\x1a*.yeying.api.support.CollectSupportResponse"\x00\x42\x14Z\x12yeying/api/supportb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.support.support_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\022yeying/api/support"
    _globals["_SUPPORTCODEENUM"]._serialized_start = 699
    _globals["_SUPPORTCODEENUM"]._serialized_end = 782
    _globals["_COLLECTSUPPORTREQUEST"]._serialized_start = 90
    _globals["_COLLECTSUPPORTREQUEST"]._serialized_end = 224
    _globals["_COLLECTSUPPORTREQUESTBODY"]._serialized_start = 227
    _globals["_COLLECTSUPPORTREQUESTBODY"]._serialized_end = 361
    _globals["_FAQMETADATA"]._serialized_start = 363
    _globals["_FAQMETADATA"]._serialized_end = 477
    _globals["_COLLECTSUPPORTRESPONSE"]._serialized_start = 480
    _globals["_COLLECTSUPPORTRESPONSE"]._serialized_end = 616
    _globals["_COLLECTSUPPORTRESPONSEBODY"]._serialized_start = 618
    _globals["_COLLECTSUPPORTRESPONSEBODY"]._serialized_end = 697
    _globals["_SUPPORT"]._serialized_start = 784
    _globals["_SUPPORT"]._serialized_end = 893
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/content/content.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/content/content.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n yeying/api/content/content.proto\x12\x12yeying.api.content\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"C\n\x0fValidateRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"D\n\x10ValidateResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader2b\n\x07\x43ontent\x12W\n\x08validate\x12#.yeying.api.content.ValidateRequest\x1a$.yeying.api.content.ValidateResponse"\x00\x42\x14Z\x12yeying/api/contentb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.content.content_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\022yeying/api/content"
    _globals["_VALIDATEREQUEST"]._serialized_start = 119
    _globals["_VALIDATEREQUEST"]._serialized_end = 186
    _globals["_VALIDATERESPONSE"]._serialized_start = 188
    _globals["_VALIDATERESPONSE"]._serialized_end = 256
    _globals["_CONTENT"]._serialized_start = 258
    _globals["_CONTENT"]._serialized_end = 356
# @@protoc_insertion_point(module_scope)



import binascii
import hashlib

from ecdsa import keys, util, curves


# 因为在生成签名的过程中每次都会选择一个新的随机数k，即使使用的是相同的私钥和相同的消息内容，由于k的不同，最终生成的（r, s）对也会不同，
# 因此签名每次都是唯一的
def sign(private_key, data, sigencode=util.sigencode_der):
    signing_key = keys.SigningKey.from_string(private_key, curve=curves.SECP256k1)
    digest = hashlib.sha256(data).digest()
    return binascii.hexlify(signing_key.sign_digest(digest=digest, sigencode=sigencode))


def verify(public_key: str, data: bytes, signature: str, sigdecode=util.sigdecode_der):
    vk = keys.VerifyingKey.from_string(public_key, curve=curves.SECP256k1)
    digest = hashlib.sha256(data).digest()
    return vk.verify_digest(signature=binascii.unhexlify(signature), digest=digest, sigdecode=sigdecode)


def encode_hex(data: bytes | bytearray | memoryview) -> str:
    """
    将字节数据编码为十六进制字符串

    参数:
        data: 字节数据，支持 bytes、bytearray 或 memoryview 类型

    返回:
        str: 小写十六进制字符串

    异常:
        TypeError: 如果输入不是字节类型
    """
    # 验证输入类型
    if not isinstance(data, (bytes, bytearray, memoryview)):
        raise TypeError(f"输入必须是字节类型，但得到的是 {type(data).__name__}")

    # 使用内置方法转换为十六进制字符串
    return data.hex()


def decode_hex(hex_str: str) -> bytes:
    """
    将十六进制字符串解码为字节数组

    参数:
        hex_str: 十六进制格式的字符串

    返回:
        bytes: 解码后的字节数组

    异常:
        ValueError: 如果输入包含非十六进制字符或长度为奇数
    """
    # 检查输入是否有效
    if not isinstance(hex_str, str):
        raise TypeError(f"输入必须是字符串，但得到的是 {type(hex_str).__name__}")

    # 移除可能存在的空格和前缀
    cleaned = hex_str.strip().lower()
    if cleaned.startswith(('0x', '0X')):
        cleaned = cleaned[2:]

    # 验证十六进制格式
    if len(cleaned) % 2 != 0:
        raise ValueError("十六进制字符串长度必须为偶数")

    if not all(c in '0123456789abcdef' for c in cleaned):
        raise ValueError("字符串包含非十六进制字符")

    # 使用内置方法转换
    return bytes.fromhex(cleaned)


# 测试代码
if __name__ == "__main__":
    hex_data = "48656c6c6f20576f726c64"  # "Hello World"
    byte_data = decode_hex(hex_data)
    print(byte_data)  # 输出: b'Hello World'

    data = b"Hello World"
    hex_str = encode_hex(data)
    print(hex_str)  # 输出: 48656c6c6f20576f726c64



# Generated by protobuf_init. Do not edit manually.
from .support_pb2 import CollectSupportRequest
from .support_pb2 import CollectSupportRequestBody
from .support_pb2 import FaqMetadata
from .support_pb2 import CollectSupportResponse
from .support_pb2 import CollectSupportResponseBody
from .support_pb2 import SupportCodeEnum
from .support_pb2_grpc import SupportServicer
from .support_pb2_grpc import SupportStub
from .support_pb2_grpc import add_SupportServicer_to_server
from .support_pb2_grpc import Support



class UserCustomException(Exception):
    def __init__(self, message):
        super().__init__(message)


class PermissionDeniedException(UserCustomException):
    def __init__(self, message):
        super().__init__(message=message)


class UnavailableException(UserCustomException):
    def __init__(self, message):
        super().__init__(message=message)


class UnauthenticatedException(UserCustomException):
    def __init__(self, message):
        super().__init__(message=message)


class LimitExceededException(UserCustomException):
    def __init__(self, message):
        super().__init__(message=message)


class AlreadyExistException(UserCustomException):
    def __init__(self, message):
        super().__init__(message=message)


class NotFoundException(UserCustomException):
    def __init__(self, message):
        super().__init__(message=message)


class InvalidArgumentException(UserCustomException):
    def __init__(self, message):
        super().__init__(message=message)



from datetime import datetime, timedelta, timezone

from dateutil import parser
from dateutil import tz


def get_current_utc_datetime():
    return convert_to_utc_datetime(datetime.now())


def get_current_utc_string():
    return format_datetime(get_current_utc_datetime())


def get_current_iso_string():
    now_utc = datetime.now(timezone.utc)
    return now_utc.isoformat(timespec="milliseconds").replace("+00:00", "Z")


def parse_datetime(s):
    return parser.isoparse(s)


def is_expired(s, minutes):
    # 解析ISO字符串
    time_parsed = parse_datetime(s)

    # 获取当前时间并保留时区信息
    now = datetime.now(time_parsed.tzinfo)

    # 计算5分钟之后的时间
    five_minutes_later = time_parsed + timedelta(minutes=minutes)

    # 比较时间，判断是否超过5分钟之后
    return now > five_minutes_later


def format_datetime(dt):
    formatted_dt = dt.isoformat(timespec="milliseconds")
    return formatted_dt.replace("+00:00", "Z")


def convert_to_local_datetime(dt):
    return dt.astimezone(tz.tzlocal())


def convert_to_utc_datetime(dt):
    return dt.astimezone(tz.tzutc())


def plus_second(dt: datetime, seconds: int) -> datetime:
    """
    向 datetime 对象添加指定的秒数

    :param dt: 原始 datetime 对象
    :param seconds: 要添加的秒数
    :return: 添加秒数后的新 datetime 对象

    >>> now = datetime.utcnow()
    >>> future = plus_second(now, 3600)  # 添加 1 小时（3600 秒）
    """
    return dt + timedelta(seconds=seconds)


def to_iso(dt: datetime) -> str:
    """
    将 datetime 对象转换为 ISO 8601 格式字符串

    :param dt: 要转换的 datetime 对象
    :return: ISO 8601 格式的字符串表示
    :example:
        now = datetime.now(timezone.utc)
        iso_str = to_iso(now)  # 返回 "2023-05-15T12:34:56.789+00:00"
    """
    # 确保 datetime 对象是带时区的
    if dt.tzinfo is None:
        dt = dt.replace(tzinfo=timezone.utc)

    # 转换为 ISO 格式字符串
    return dt.isoformat()


def from_iso(s: str) -> datetime:
    """
    从 ISO 字符串创建 datetime 对象

    :param s: ISO 8601 格式的日期字符串
    :return: 解析后的 datetime 对象
    :raises ValueError: 如果字符串无法解析则抛出错误
    :example:
        dt = from_iso("2023-05-15T12:34:56.789+00:00")
    """
    try:
        # 解析 ISO 格式字符串
        dt = datetime.fromisoformat(s)

        # 如果解析后的对象没有时区信息，添加 UTC 时区
        if dt.tzinfo is None:
            return dt.replace(tzinfo=timezone.utc)
        return dt
    except Exception as e:
        raise ValueError(f"无法解析 ISO 字符串: {s}") from e


# Generated by protobuf_init. Do not edit manually.
from .session_pb2 import CreateSessionRequest
from .session_pb2 import CreateSessionRequestBody
from .session_pb2 import CreateSessionResponse
from .session_pb2 import CreateSessionResponseBody
from .session_pb2 import SessionDetailRequest
from .session_pb2 import SessionDetailRequestBody
from .session_pb2 import SessionDetailResponse
from .session_pb2 import SessionDetailResponseBody
from .session_pb2 import SessionDetail
from .session_pb2 import DeleteSessionRequest
from .session_pb2 import DeleteSessionRequestBody
from .session_pb2 import DeleteSessionResponse
from .session_pb2 import DeleteSessionResponseBody
from .session_pb2 import SearchSessionRequest
from .session_pb2 import SearchSessionRequestBody
from .session_pb2 import SearchSessionCondition
from .session_pb2 import SearchSessionResponse
from .session_pb2 import SearchSessionResponseBody
from .session_pb2 import UpdateSessionRequest
from .session_pb2 import UpdateSessionRequestBody
from .session_pb2 import UpdateSessionResponse
from .session_pb2 import UpdateSessionResponseBody
from .session_pb2 import SessionMetadata
from .session_pb2_grpc import SessionServicer
from .session_pb2_grpc import SessionStub
from .session_pb2_grpc import add_SessionServicer_to_server
from .session_pb2_grpc import Session



from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.common import code_pb2 as _code_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DepositRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DepositRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DepositRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DepositRequestBody(_message.Message):
    __slots__ = ("cipher", "protocol")
    CIPHER_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    cipher: str
    protocol: str
    def __init__(self, cipher: _Optional[str] = ..., protocol: _Optional[str] = ...) -> None: ...

class DepositResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DepositResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DepositResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DepositResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class RetrieveRequest(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...

class RetrieveResponse(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...

class ShareRequest(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...

class ShareResponse(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...

class QueryRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: QueryRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[QueryRequestBody, _Mapping]] = ...,
    ) -> None: ...

class QueryRequestBody(_message.Message):
    __slots__ = ("serviceCode",)
    SERVICECODE_FIELD_NUMBER: _ClassVar[int]
    serviceCode: _code_pb2.ServiceCodeEnum
    def __init__(self, serviceCode: _Optional[_Union[_code_pb2.ServiceCodeEnum, str]] = ...) -> None: ...

class QueryResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: QueryResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[QueryResponseBody, _Mapping]] = ...,
    ) -> None: ...

class QueryResponseBody(_message.Message):
    __slots__ = ("status", "cipher", "protocol")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CIPHER_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    cipher: str
    protocol: str
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        cipher: _Optional[str] = ...,
        protocol: _Optional[str] = ...,
    ) -> None: ...

class CancelRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CancelRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CancelRequestBody, _Mapping]] = ...,
    ) -> None: ...

class CancelRequestBody(_message.Message):
    __slots__ = ("did",)
    DID_FIELD_NUMBER: _ClassVar[int]
    did: str
    def __init__(self, did: _Optional[str] = ...) -> None: ...

class CancelResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CancelResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CancelResponseBody, _Mapping]] = ...,
    ) -> None: ...

class CancelResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as _meta_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class MessageListRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MessageListRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MessageListRequestBody, _Mapping]] = ...,
    ) -> None: ...

class MessageListRequestBody(_message.Message):
    __slots__ = ("pageIndex", "pageSize")
    PAGEINDEX_FIELD_NUMBER: _ClassVar[int]
    PAGESIZE_FIELD_NUMBER: _ClassVar[int]
    pageIndex: _wrappers_pb2.Int32Value
    pageSize: _wrappers_pb2.Int32Value
    def __init__(
        self,
        pageIndex: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...,
        pageSize: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...,
    ) -> None: ...

class MessageListResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MessageListResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MessageListResponseBody, _Mapping]] = ...,
    ) -> None: ...

class MessageListResponseBody(_message.Message):
    __slots__ = ("status", "list", "total")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    LIST_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    list: _containers.RepeatedCompositeFieldContainer[_meta_pb2.MessageMetadata]
    total: int
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        list: _Optional[_Iterable[_Union[_meta_pb2.MessageMetadata, _Mapping]]] = ...,
        total: _Optional[int] = ...,
    ) -> None: ...

class CountRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CountRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CountRequestBody, _Mapping]] = ...,
    ) -> None: ...

class CountRequestBody(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CountResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CountResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CountResponseBody, _Mapping]] = ...,
    ) -> None: ...

class CountResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _containers.RepeatedCompositeFieldContainer[CountMetadata]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Iterable[_Union[CountMetadata, _Mapping]]] = ...,
    ) -> None: ...

class CountMetadata(_message.Message):
    __slots__ = ("type", "count")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    type: int
    count: int
    def __init__(self, type: _Optional[int] = ..., count: _Optional[int] = ...) -> None: ...

class ListByRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ListByRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ListByRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ListByRequestBody(_message.Message):
    __slots__ = ("status", "type")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    status: int
    type: int
    def __init__(self, status: _Optional[int] = ..., type: _Optional[int] = ...) -> None: ...

class ListByResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ListByResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ListByResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ListByResponseBody(_message.Message):
    __slots__ = ("status", "meta", "count")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _containers.RepeatedCompositeFieldContainer[_meta_pb2.MessageMetadata]
    count: int
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Iterable[_Union[_meta_pb2.MessageMetadata, _Mapping]]] = ...,
        count: _Optional[int] = ...,
    ) -> None: ...

class MarkAsReadRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MarkAsReadRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MarkAsReadRequestBody, _Mapping]] = ...,
    ) -> None: ...

class MarkAsReadRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class MarkAsReadResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MarkAsReadResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MarkAsReadResponseBody, _Mapping]] = ...,
    ) -> None: ...

class MarkAsReadResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/asset/recycle.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/asset/recycle.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.asset import asset_pb2 as yeying_dot_api_dot_asset_dot_asset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eyeying/api/asset/recycle.proto\x12\x10yeying.api.asset\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/asset/asset.proto"\x8c\x01\n\x19SearchDeletedAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.asset.SearchDeletedAssetRequestBody"\x88\x01\n\x1dSearchDeletedAssetRequestBody\x12\x39\n\tcondition\x18\x01 \x01(\x0b\x32&.yeying.api.asset.SearchAssetCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\x8e\x01\n\x1aSearchDeletedAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.SearchDeletedAssetResponseBody"\x8b\x01\n\x1eSearchDeletedAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x06\x61ssets\x18\x02 \x03(\x0b\x32&.yeying.api.asset.DeletedAssetMetadata"\x8e\x01\n\x1aRecoverDeletedAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.RecoverDeletedAssetRequestBody"C\n\x1eRecoverDeletedAssetRequestBody\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x02 \x01(\t"\x90\x01\n\x1bRecoverDeletedAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.asset.RecoverDeletedAssetResponseBody"T\n\x1fRecoverDeletedAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x8c\x01\n\x19RemoveDeletedAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.asset.RemoveDeletedAssetRequestBody"B\n\x1dRemoveDeletedAssetRequestBody\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x02 \x01(\t"\x8e\x01\n\x1aRemoveDeletedAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.RemoveDeletedAssetResponseBody"S\n\x1eRemoveDeletedAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"Y\n\x14\x44\x65letedAssetMetadata\x12.\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata\x12\x11\n\tdeletedAt\x18\r \x01(\t2\xc1\x02\n\x07Recycle\x12\x65\n\x06Search\x12+.yeying.api.asset.SearchDeletedAssetRequest\x1a,.yeying.api.asset.SearchDeletedAssetResponse"\x00\x12h\n\x07Recover\x12,.yeying.api.asset.RecoverDeletedAssetRequest\x1a-.yeying.api.asset.RecoverDeletedAssetResponse"\x00\x12\x65\n\x06Remove\x12+.yeying.api.asset.RemoveDeletedAssetRequest\x1a,.yeying.api.asset.RemoveDeletedAssetResponse"\x00\x42\x12Z\x10yeying/api/assetb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.asset.recycle_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/asset"
    _globals["_SEARCHDELETEDASSETREQUEST"]._serialized_start = 116
    _globals["_SEARCHDELETEDASSETREQUEST"]._serialized_end = 256
    _globals["_SEARCHDELETEDASSETREQUESTBODY"]._serialized_start = 259
    _globals["_SEARCHDELETEDASSETREQUESTBODY"]._serialized_end = 395
    _globals["_SEARCHDELETEDASSETRESPONSE"]._serialized_start = 398
    _globals["_SEARCHDELETEDASSETRESPONSE"]._serialized_end = 540
    _globals["_SEARCHDELETEDASSETRESPONSEBODY"]._serialized_start = 543
    _globals["_SEARCHDELETEDASSETRESPONSEBODY"]._serialized_end = 682
    _globals["_RECOVERDELETEDASSETREQUEST"]._serialized_start = 685
    _globals["_RECOVERDELETEDASSETREQUEST"]._serialized_end = 827
    _globals["_RECOVERDELETEDASSETREQUESTBODY"]._serialized_start = 829
    _globals["_RECOVERDELETEDASSETREQUESTBODY"]._serialized_end = 896
    _globals["_RECOVERDELETEDASSETRESPONSE"]._serialized_start = 899
    _globals["_RECOVERDELETEDASSETRESPONSE"]._serialized_end = 1043
    _globals["_RECOVERDELETEDASSETRESPONSEBODY"]._serialized_start = 1045
    _globals["_RECOVERDELETEDASSETRESPONSEBODY"]._serialized_end = 1129
    _globals["_REMOVEDELETEDASSETREQUEST"]._serialized_start = 1132
    _globals["_REMOVEDELETEDASSETREQUEST"]._serialized_end = 1272
    _globals["_REMOVEDELETEDASSETREQUESTBODY"]._serialized_start = 1274
    _globals["_REMOVEDELETEDASSETREQUESTBODY"]._serialized_end = 1340
    _globals["_REMOVEDELETEDASSETRESPONSE"]._serialized_start = 1343
    _globals["_REMOVEDELETEDASSETRESPONSE"]._serialized_end = 1485
    _globals["_REMOVEDELETEDASSETRESPONSEBODY"]._serialized_start = 1487
    _globals["_REMOVEDELETEDASSETRESPONSEBODY"]._serialized_end = 1570
    _globals["_DELETEDASSETMETADATA"]._serialized_start = 1572
    _globals["_DELETEDASSETMETADATA"]._serialized_end = 1661
    _globals["_RECYCLE"]._serialized_start = 1664
    _globals["_RECYCLE"]._serialized_end = 1985
# @@protoc_insertion_point(module_scope)



# -*- coding:utf-8 -*-
from yeying.api.common import DigitalFormatEnum


def get_ext_list_by_digital_format(digital_format: DigitalFormatEnum):
    cases = {
        DigitalFormatEnum.DIGITAL_FORMAT_IMAGE: [".jpg", "jpeg", ".gif", ".png", "webp"],
        DigitalFormatEnum.DIGITAL_FORMAT_VIDEO: [".mp4", ".avi", ".mov", ".flv"],
        DigitalFormatEnum.DIGITAL_FORMAT_AUDIO: [".mp3", ".wav", ".ogg"],
        DigitalFormatEnum.DIGITAL_FORMAT_TEXT: [".txt", ".csv", ".html", ".css"],
        DigitalFormatEnum.DIGITAL_FORMAT_APP: [".id", ".session", ".app", ".metadata", ".state", ".prompt"],
        DigitalFormatEnum.DIGITAL_FORMAT_OTHER: [],
    }
    return cases.get(digital_format, [])


def get_digital_format_by_name(name: str) -> DigitalFormatEnum:
    for digitalFormat in DigitalFormatEnum.values():
        res = next((item for item in get_ext_list_by_digital_format(digitalFormat) if name.endswith(item)), None)
        if res:
            return digitalFormat
    return DigitalFormatEnum.DIGITAL_FORMAT_OTHER



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/event/event.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/event/event.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cyeying/api/event/event.proto\x12\x10yeying.api.event\x1a\x1fyeying/api/common/message.proto"\xcc\x04\n\rEventMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12-\n\x04type\x18\x02 \x01(\x0e\x32\x1f.yeying.api.event.EventTypeEnum\x12\x11\n\tproducers\x18\x03 \x03(\t\x12\x11\n\tconsumers\x18\x04 \x03(\t\x12\x33\n\tsignature\x18\x05 \x01(\x0b\x32 .yeying.api.event.EventSignature\x12\x0e\n\x06\x65xtend\x18\x06 \x01(\t\x12\x11\n\tcreatedAt\x18\x07 \x01(\t\x12\x13\n\x0bprocessedAt\x18\x08 \x01(\t\x12\x38\n\rnotifyContent\x18\t \x01(\x0b\x32\x1f.yeying.api.event.NotifyContentH\x00\x12\x36\n\x0c\x61pplyContent\x18\n \x01(\x0b\x32\x1e.yeying.api.event.ApplyContentH\x00\x12\x38\n\rcustomContent\x18\x0b \x01(\x0b\x32\x1f.yeying.api.event.CustomContentH\x00\x12\x38\n\rnotifyOpinion\x18\x0c \x01(\x0b\x32\x1f.yeying.api.event.NotifyOpinionH\x01\x12\x36\n\x0c\x61pplyOpinion\x18\r \x01(\x0b\x32\x1e.yeying.api.event.ApplyOpinionH\x01\x12\x38\n\rcustomOpinion\x18\x0e \x01(\x0b\x32\x1f.yeying.api.event.CustomOpinionH\x01\x42\t\n\x07\x63ontentB\t\n\x07opinion"\xe0\x01\n\x0fSignatureObject\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12-\n\x04type\x18\x02 \x01(\x0e\x32\x1f.yeying.api.event.EventTypeEnum\x12\x11\n\tproducers\x18\x03 \x03(\t\x12\x11\n\tconsumers\x18\x04 \x03(\t\x12\x11\n\tsignature\x18\x05 \x01(\x0c\x12\x0e\n\x06\x65xtend\x18\x06 \x01(\t\x12\x11\n\tcreatedAt\x18\x07 \x01(\t\x12\x13\n\x0bprocessedAt\x18\x08 \x01(\t\x12\x0f\n\x07opinion\x18\t \x01(\x0c\x12\x0f\n\x07\x63ontent\x18\n \x01(\x0c"6\n\x0e\x45ventSignature\x12\x11\n\tproducers\x18\x01 \x03(\t\x12\x11\n\tconsumers\x18\x02 \x03(\t"-\n\rCustomContent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06object\x18\x02 \x01(\t"\x1f\n\x0c\x41pplyContent\x12\x0f\n\x07\x61pplier\x18\x01 \x01(\t"J\n\rNotifyContent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.yeying.api.event.NotifyItem"M\n\nNotifyItem\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x32\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32".yeying.api.event.NotifyActionEnum"v\n\x0eProduceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.event.ProduceRequestBody"D\n\x12ProduceRequestBody\x12.\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1f.yeying.api.event.EventMetadata"x\n\x0fProduceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.event.ProduceResponseBody"H\n\x13ProduceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"v\n\x0e\x43onsumeRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.event.ConsumeRequestBody"G\n\x12\x43onsumeRequestBody\x12\x31\n\x08metadata\x18\x01 \x01(\x0b\x32\x1f.yeying.api.event.EventMetadata""\n\rNotifyOpinion\x12\x11\n\tprocessed\x18\x01 \x01(\t"c\n\x0c\x41pplyOpinion\x12\x31\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32!.yeying.api.event.ApplyActionEnum\x12\r\n\x05\x63\x61use\x18\x02 \x01(\t\x12\x11\n\tprocessed\x18\x03 \x01(\t"-\n\rCustomOpinion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06object\x18\x02 \x01(\t"x\n\x0f\x43onsumeResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.event.ConsumeResponseBody"H\n\x13\x43onsumeResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus*\x82\x01\n\rEventTypeEnum\x12\x16\n\x12\x45VENT_TYPE_UNKNOWN\x10\x00\x12\x15\n\x11\x45VENT_TYPE_REMIND\x10\x01\x12\x15\n\x11\x45VENT_TYPE_NOTIFY\x10\x02\x12\x14\n\x10\x45VENT_TYPE_APPLY\x10\x03\x12\x15\n\x11\x45VENT_TYPE_CUSTOM\x10\x04*^\n\x0f\x41pplyActionEnum\x12\x18\n\x14\x41PPLY_ACTION_UNKNOWN\x10\x00\x12\x17\n\x13\x41PPLY_ACTION_PASSED\x10\x01\x12\x18\n\x14\x41PPLY_ACTION_REFUSED\x10\x02*r\n\x10NotifyActionEnum\x12\x19\n\x15NOTIFY_ACTION_UNKNOWN\x10\x00\x12\x15\n\x11NOTIFY_ACTION_ADD\x10\x01\x12\x15\n\x11NOTIFY_ACTION_DEL\x10\x02\x12\x15\n\x11NOTIFY_ACTION_MOD\x10\x03\x32\xab\x01\n\x05\x45vent\x12P\n\x07Produce\x12 .yeying.api.event.ProduceRequest\x1a!.yeying.api.event.ProduceResponse"\x00\x12P\n\x07\x43onsume\x12 .yeying.api.event.ConsumeRequest\x1a!.yeying.api.event.ConsumeResponse"\x00\x42\x12Z\x10yeying/api/eventb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.event.event_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/event"
    _globals["_EVENTTYPEENUM"]._serialized_start = 2152
    _globals["_EVENTTYPEENUM"]._serialized_end = 2282
    _globals["_APPLYACTIONENUM"]._serialized_start = 2284
    _globals["_APPLYACTIONENUM"]._serialized_end = 2378
    _globals["_NOTIFYACTIONENUM"]._serialized_start = 2380
    _globals["_NOTIFYACTIONENUM"]._serialized_end = 2494
    _globals["_EVENTMETADATA"]._serialized_start = 84
    _globals["_EVENTMETADATA"]._serialized_end = 672
    _globals["_SIGNATUREOBJECT"]._serialized_start = 675
    _globals["_SIGNATUREOBJECT"]._serialized_end = 899
    _globals["_EVENTSIGNATURE"]._serialized_start = 901
    _globals["_EVENTSIGNATURE"]._serialized_end = 955
    _globals["_CUSTOMCONTENT"]._serialized_start = 957
    _globals["_CUSTOMCONTENT"]._serialized_end = 1002
    _globals["_APPLYCONTENT"]._serialized_start = 1004
    _globals["_APPLYCONTENT"]._serialized_end = 1035
    _globals["_NOTIFYCONTENT"]._serialized_start = 1037
    _globals["_NOTIFYCONTENT"]._serialized_end = 1111
    _globals["_NOTIFYITEM"]._serialized_start = 1113
    _globals["_NOTIFYITEM"]._serialized_end = 1190
    _globals["_PRODUCEREQUEST"]._serialized_start = 1192
    _globals["_PRODUCEREQUEST"]._serialized_end = 1310
    _globals["_PRODUCEREQUESTBODY"]._serialized_start = 1312
    _globals["_PRODUCEREQUESTBODY"]._serialized_end = 1380
    _globals["_PRODUCERESPONSE"]._serialized_start = 1382
    _globals["_PRODUCERESPONSE"]._serialized_end = 1502
    _globals["_PRODUCERESPONSEBODY"]._serialized_start = 1504
    _globals["_PRODUCERESPONSEBODY"]._serialized_end = 1576
    _globals["_CONSUMEREQUEST"]._serialized_start = 1578
    _globals["_CONSUMEREQUEST"]._serialized_end = 1696
    _globals["_CONSUMEREQUESTBODY"]._serialized_start = 1698
    _globals["_CONSUMEREQUESTBODY"]._serialized_end = 1769
    _globals["_NOTIFYOPINION"]._serialized_start = 1771
    _globals["_NOTIFYOPINION"]._serialized_end = 1805
    _globals["_APPLYOPINION"]._serialized_start = 1807
    _globals["_APPLYOPINION"]._serialized_end = 1906
    _globals["_CUSTOMOPINION"]._serialized_start = 1908
    _globals["_CUSTOMOPINION"]._serialized_end = 1953
    _globals["_CONSUMERESPONSE"]._serialized_start = 1955
    _globals["_CONSUMERESPONSE"]._serialized_end = 2075
    _globals["_CONSUMERESPONSEBODY"]._serialized_start = 2077
    _globals["_CONSUMERESPONSEBODY"]._serialized_end = 2149
    _globals["_EVENT"]._serialized_start = 2497
    _globals["_EVENT"]._serialized_end = 2668
# @@protoc_insertion_point(module_scope)



from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.common import code_pb2 as _code_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ValidateRequest(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...

class ValidateResponse(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/homework.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/homework.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)yeying/api/apps/zuoyepigai/homework.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x8a\x01\n\x13HomeworkListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.HomeworkListRequestBody"&\n\x17HomeworkListRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"\x8c\x01\n\x14HomeworkListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.HomeworkListResponseBody"\x89\x01\n\x18HomeworkListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12:\n\x04list\x18\x02 \x03(\x0b\x32,.yeying.api.apps.zuoyepigai.HomeworkMetadata"\x8e\x01\n\x15HomeworkDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.HomeworkDetailRequestBody"(\n\x19HomeworkDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x90\x01\n\x16HomeworkDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.apps.zuoyepigai.HomeworkDetailResponseBody"\x8b\x01\n\x1aHomeworkDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12:\n\x04meta\x18\x02 \x01(\x0b\x32,.yeying.api.apps.zuoyepigai.HomeworkMetadata2\xea\x01\n\x08Homework\x12k\n\x04List\x12/.yeying.api.apps.zuoyepigai.HomeworkListRequest\x1a\x30.yeying.api.apps.zuoyepigai.HomeworkListResponse"\x00\x12q\n\x06\x44\x65tail\x12\x31.yeying.api.apps.zuoyepigai.HomeworkDetailRequest\x1a\x32.yeying.api.apps.zuoyepigai.HomeworkDetailResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.homework_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_HOMEWORKLISTREQUEST"]._serialized_start = 146
    _globals["_HOMEWORKLISTREQUEST"]._serialized_end = 284
    _globals["_HOMEWORKLISTREQUESTBODY"]._serialized_start = 286
    _globals["_HOMEWORKLISTREQUESTBODY"]._serialized_end = 324
    _globals["_HOMEWORKLISTRESPONSE"]._serialized_start = 327
    _globals["_HOMEWORKLISTRESPONSE"]._serialized_end = 467
    _globals["_HOMEWORKLISTRESPONSEBODY"]._serialized_start = 470
    _globals["_HOMEWORKLISTRESPONSEBODY"]._serialized_end = 607
    _globals["_HOMEWORKDETAILREQUEST"]._serialized_start = 610
    _globals["_HOMEWORKDETAILREQUEST"]._serialized_end = 752
    _globals["_HOMEWORKDETAILREQUESTBODY"]._serialized_start = 754
    _globals["_HOMEWORKDETAILREQUESTBODY"]._serialized_end = 794
    _globals["_HOMEWORKDETAILRESPONSE"]._serialized_start = 797
    _globals["_HOMEWORKDETAILRESPONSE"]._serialized_end = 941
    _globals["_HOMEWORKDETAILRESPONSEBODY"]._serialized_start = 944
    _globals["_HOMEWORKDETAILRESPONSEBODY"]._serialized_end = 1083
    _globals["_HOMEWORK"]._serialized_start = 1086
    _globals["_HOMEWORK"]._serialized_end = 1320
# @@protoc_insertion_point(module_scope)



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class UserStatusEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    USER_STATUS_UNKNOWN: _ClassVar[UserStatusEnum]
    USER_STATUS_ACTIVE: _ClassVar[UserStatusEnum]
    USER_STATUS_OFFLINE: _ClassVar[UserStatusEnum]
    USER_STATUS_DISABLE: _ClassVar[UserStatusEnum]
    USER_STATUS_LOCK: _ClassVar[UserStatusEnum]
    USER_STATUS_UNVERIFIED: _ClassVar[UserStatusEnum]
    USER_STATUS_DELETED: _ClassVar[UserStatusEnum]
    USER_STATUS_DORMANT: _ClassVar[UserStatusEnum]
    USER_STATUS_FREEZE: _ClassVar[UserStatusEnum]
    USER_STATUS_AUDIT: _ClassVar[UserStatusEnum]
    USER_STATUS_REFUSED: _ClassVar[UserStatusEnum]

class UserRoleEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    USER_ROLE_UNKNOWN: _ClassVar[UserRoleEnum]
    USER_ROLE_OWNER: _ClassVar[UserRoleEnum]
    USER_ROLE_NORMAL: _ClassVar[UserRoleEnum]

USER_STATUS_UNKNOWN: UserStatusEnum
USER_STATUS_ACTIVE: UserStatusEnum
USER_STATUS_OFFLINE: UserStatusEnum
USER_STATUS_DISABLE: UserStatusEnum
USER_STATUS_LOCK: UserStatusEnum
USER_STATUS_UNVERIFIED: UserStatusEnum
USER_STATUS_DELETED: UserStatusEnum
USER_STATUS_DORMANT: UserStatusEnum
USER_STATUS_FREEZE: UserStatusEnum
USER_STATUS_AUDIT: UserStatusEnum
USER_STATUS_REFUSED: UserStatusEnum
USER_ROLE_UNKNOWN: UserRoleEnum
USER_ROLE_OWNER: UserRoleEnum
USER_ROLE_NORMAL: UserRoleEnum

class UpdateStatusRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateStatusRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateStatusRequestBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateStatusRequestBody(_message.Message):
    __slots__ = ("did", "status")
    DID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    did: str
    status: UserStatusEnum
    def __init__(self, did: _Optional[str] = ..., status: _Optional[_Union[UserStatusEnum, str]] = ...) -> None: ...

class UpdateStatusResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateStatusResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateStatusResponseBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateStatusResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class UserListRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UserListRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UserListRequestBody, _Mapping]] = ...,
    ) -> None: ...

class UserListRequestBody(_message.Message):
    __slots__ = ("pageIndex", "pageSize")
    PAGEINDEX_FIELD_NUMBER: _ClassVar[int]
    PAGESIZE_FIELD_NUMBER: _ClassVar[int]
    pageIndex: _wrappers_pb2.Int32Value
    pageSize: _wrappers_pb2.Int32Value
    def __init__(
        self,
        pageIndex: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...,
        pageSize: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...,
    ) -> None: ...

class UserListResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UserListResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UserListResponseBody, _Mapping]] = ...,
    ) -> None: ...

class UserListResponseBody(_message.Message):
    __slots__ = ("status", "list", "total")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    LIST_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    list: _containers.RepeatedCompositeFieldContainer[UserDetail]
    total: int
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        list: _Optional[_Iterable[_Union[UserDetail, _Mapping]]] = ...,
        total: _Optional[int] = ...,
    ) -> None: ...

class UserMetadata(_message.Message):
    __slots__ = ("did", "name", "avatar", "createdAt", "updatedAt", "signature", "telephone", "email")
    DID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    AVATAR_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    TELEPHONE_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    did: str
    name: str
    avatar: str
    createdAt: str
    updatedAt: str
    signature: str
    telephone: str
    email: str
    def __init__(
        self,
        did: _Optional[str] = ...,
        name: _Optional[str] = ...,
        avatar: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        updatedAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
        telephone: _Optional[str] = ...,
        email: _Optional[str] = ...,
    ) -> None: ...

class UserState(_message.Message):
    __slots__ = ("owner", "did", "role", "status", "createdAt", "updatedAt", "signature")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    DID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    owner: str
    did: str
    role: UserRoleEnum
    status: UserStatusEnum
    createdAt: str
    updatedAt: str
    signature: str
    def __init__(
        self,
        owner: _Optional[str] = ...,
        did: _Optional[str] = ...,
        role: _Optional[_Union[UserRoleEnum, str]] = ...,
        status: _Optional[_Union[UserStatusEnum, str]] = ...,
        createdAt: _Optional[str] = ...,
        updatedAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...

class AddUserRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddUserRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AddUserRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AddUserRequestBody(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: UserMetadata
    def __init__(self, user: _Optional[_Union[UserMetadata, _Mapping]] = ...) -> None: ...

class AddUserResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddUserResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AddUserResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AddUserResponseBody(_message.Message):
    __slots__ = ("status", "user")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    user: UserMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        user: _Optional[_Union[UserMetadata, _Mapping]] = ...,
    ) -> None: ...

class UpdateUserRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateUserRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateUserRequestBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateUserRequestBody(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: UserMetadata
    def __init__(self, user: _Optional[_Union[UserMetadata, _Mapping]] = ...) -> None: ...

class UpdateUserResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateUserResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateUserResponseBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateUserResponseBody(_message.Message):
    __slots__ = ("status", "user")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    user: UserMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        user: _Optional[_Union[UserMetadata, _Mapping]] = ...,
    ) -> None: ...

class DeleteUserRequest(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...

class DeleteUserResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteUserResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteUserResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteUserResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class UserDetailRequest(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...

class UserDetailResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UserDetailResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UserDetailResponseBody, _Mapping]] = ...,
    ) -> None: ...

class UserDetailResponseBody(_message.Message):
    __slots__ = ("status", "detail")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    detail: UserDetail
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        detail: _Optional[_Union[UserDetail, _Mapping]] = ...,
    ) -> None: ...

class UserDetail(_message.Message):
    __slots__ = ("user", "state")
    USER_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    user: UserMetadata
    state: UserState
    def __init__(
        self, user: _Optional[_Union[UserMetadata, _Mapping]] = ..., state: _Optional[_Union[UserState, _Mapping]] = ...
    ) -> None: ...



# -*- coding:utf-8 -*-
from google.protobuf.json_format import MessageToJson
from yeying.client.utils.date_utils import get_current_utc_string

from yeying.api.common import ResponseCodeEnum
from yeying.client.provider.base_provider import BaseProvider
from yeying.api.config import config_pb2_grpc, config_pb2
import grpc
from yeying.client.utils import log_utils

log = log_utils.get_logger(__name__)


"""
提供对资产的管理，包括查询、版本获取、详情查看、删除等操作
"""


class ConfigProvider(BaseProvider):

    def __init__(self, **kw):
        super(ConfigProvider, self).__init__(**kw)
        # 资产元信息
        self.config_client = config_pb2_grpc.ConfigStub(grpc.insecure_channel(self.option.proxy))

    def get(
        self, key: str, config_type: config_pb2.ConfigTypeEnum = config_pb2.ConfigTypeEnum.CONFIG_TYPE_USER
    ) -> config_pb2.GetConfigResponse:
        """
        kv 配置查询
        :param key: 键
        :param config_type: 配置类型 - 枚举 config_pb2.ConfigTypeEnum
        :return: config_pb2.GetConfigResponse
        """

        body = config_pb2.GetConfigRequestBody(key=key, type=config_type)
        header = self.authenticate.create_header(body=body)
        request = config_pb2.GetConfigRequest(header=header, body=body)
        response: config_pb2.GetConfigResponse = self.config_client.Get(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"get error, response={MessageToJson(response)}")
        return response

    def set(self, key: str, value: str) -> config_pb2.SetConfigResponse:
        """
        kv 配置添加
        :param key: key 配置信息
        :param value: value 配置信息
        :return: config_pb2.GetConfigResponse
        """
        config: config_pb2.ConfigMetadata = config_pb2.ConfigMetadata(
            key=key,
            value=value,
            owner=self.authenticate.get_did(),
            createdAt=get_current_utc_string(),
            updatedAt=get_current_utc_string(),
        )
        config.signature = self.authenticate.sign_data(config.SerializeToString())
        body = config_pb2.SetConfigRequestBody(config=config)
        header = self.authenticate.create_header(body=body)
        request = config_pb2.SetConfigRequest(header=header, body=body)
        response: config_pb2.SetConfigResponse = self.config_client.Set(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"set error, response={MessageToJson(response)}")
        return response



# -*- coding:utf-8 -*-
from google.protobuf.json_format import MessageToJson

from yeying.api.common import ResponseCodeEnum, message_pb2
from yeying.client.provider.base_provider import BaseProvider
from yeying.api.asset import asset_pb2_grpc, asset_pb2
import grpc
from yeying.client.utils import log_utils
from yeying.client.utils.date_utils import get_current_utc_string

log = log_utils.get_logger(__name__)


"""
提供对资产的管理，包括查询、版本获取、详情查看、删除等操作
"""
class AssetProvider(BaseProvider):

    def __init__(self, **kw):
        super(AssetProvider, self).__init__(**kw)
        # 资产元信息
        self.asset_client = asset_pb2_grpc.AssetStub(grpc.insecure_channel(self.option.proxy))

    def sign(self, asset: asset_pb2.AssetMetadata) -> asset_pb2.SignAssetResponse:
        """
        签名资产元数据，对资产元数据进行签名，并发送签名请求到后端服务。
        :param asset:签约资产元数据
        :returns 返回签名后的资产元数据
        :throws NoPermission 没有权限
        :throws NotFound 资产不存在
        :throws ServiceUnavailable 服务不可用
        """
        asset.signature = self.authenticate.sign_data(asset.SerializeToString())
        body = asset_pb2.SignAssetRequestBody(asset=asset)
        header = self.authenticate.create_header(body=body)
        request = asset_pb2.SignAssetRequest(header=header, body=body)
        response: asset_pb2.SignAssetResponse = self.asset_client.Sign(request)
        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"sign error, response={MessageToJson(response)}")
        return response

    def detail(self, namespace_id: str, _hash: str) -> asset_pb2.AssetDetailResponse:
        """
        查询资产详情，根据命名空间 ID 和哈希值获取资产元数据
        :param namespace_id:命名空间 ID
        :param _hash:资产的哈希值
        :return:返回资产元数据
        """
        body = asset_pb2.AssetDetailRequestBody(hash=_hash, namespaceId=namespace_id)
        header = self.authenticate.create_header(body=body)
        request = asset_pb2.AssetDetailRequest(header=header, body=body)
        response: asset_pb2.AssetDetailResponse = self.asset_client.Detail(request)
        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"detail error, response={MessageToJson(response)}")
        return response

    def search(self, page: int, page_size: int, condition: asset_pb2.SearchAssetCondition=None) -> asset_pb2.SearchAssetResponse:
        """
        搜索资产，根据条件和分页参数查询资产列表
        :param page:当前页码
        :param page_size:每页显示的条目数
        :param condition:搜索条件（部分 `SearchAssetCondition` 对象）
        :return:返回搜索到的资产元数据列表
        """
        body = asset_pb2.SearchAssetRequestBody(condition=condition, page=message_pb2.RequestPage(page=page, pageSize=page_size))
        header = self.authenticate.create_header(body=body)
        request = asset_pb2.SearchAssetRequest(header=header, body=body)
        response: asset_pb2.SearchAssetResponse = self.asset_client.Search(request)
        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"search error, response={MessageToJson(response)}")
        return response

    def update(self, asset: asset_pb2.AssetMetadata) -> asset_pb2.UpdateAssetResponse:
        """
        更新资产的信息。
        :param asset:资产原数据
        :return:
        """
        detail_res: asset_pb2.AssetDetailResponse = self.detail(namespace_id=asset.namespaceId, _hash=asset.hash)
        existing = detail_res.body.asset
        if asset.name:
            existing.name = asset.name
        if asset.description:
            existing.description = asset.description
        if asset.format:
            existing.format = asset.format
        existing.updatedAt = get_current_utc_string()
        existing.signature = self.authenticate.sign_data(existing.SerializeToString())
        body = asset_pb2.UpdateAssetRequestBody(asset=existing)
        header = self.authenticate.create_header(body=body)
        request = asset_pb2.UpdateAssetRequest(header=header, body=body)
        response: asset_pb2.UpdateAssetResponse = self.asset_client.Update(request)
        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"update error, response={MessageToJson(response)}")
        return response

    def delete(self, namespace_id: str, _hash: str) -> asset_pb2.DeleteAssetResponse:
        """
        删除资产，根据命名空间 ID 和哈希值删除资产
        :param namespace_id:命名空间 ID
        :param _hash:资产的哈希值
        :return:无返回
        """
        body = asset_pb2.DeleteAssetRequestBody(hash=_hash, namespaceId=namespace_id)
        header = self.authenticate.create_header(body=body)
        request = asset_pb2.DeleteAssetRequest(header=header, body=body)
        response: asset_pb2.DeleteAssetResponse = self.asset_client.Delete(request)
        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"delete error, response={MessageToJson(response)}")
        return response


from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetStateRequest(_message.Message):
    __slots__ = ("did", "condition")
    DID_FIELD_NUMBER: _ClassVar[int]
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    did: str
    condition: str
    def __init__(self, did: _Optional[str] = ..., condition: _Optional[str] = ...) -> None: ...

class GetStateResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class TransferRequest(_message.Message):
    __slots__ = ("did",)
    DID_FIELD_NUMBER: _ClassVar[int]
    did: str
    def __init__(self, did: _Optional[str] = ...) -> None: ...

class TransferResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class PluginType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    WEB: _ClassVar[PluginType]
    SPIDER: _ClassVar[PluginType]

WEB: PluginType
SPIDER: PluginType

class SearchRequest(_message.Message):
    __slots__ = ("owner", "conditionList")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    CONDITIONLIST_FIELD_NUMBER: _ClassVar[int]
    owner: str
    conditionList: _containers.RepeatedCompositeFieldContainer[Condition]
    def __init__(
        self, owner: _Optional[str] = ..., conditionList: _Optional[_Iterable[_Union[Condition, _Mapping]]] = ...
    ) -> None: ...

class Condition(_message.Message):
    __slots__ = ("sql",)
    SQL_FIELD_NUMBER: _ClassVar[int]
    sql: str
    def __init__(self, sql: _Optional[str] = ...) -> None: ...

class SearchResponse(_message.Message):
    __slots__ = ("pluginItemList",)
    PLUGINITEMLIST_FIELD_NUMBER: _ClassVar[int]
    pluginItemList: _containers.RepeatedCompositeFieldContainer[PluginItem]
    def __init__(self, pluginItemList: _Optional[_Iterable[_Union[PluginItem, _Mapping]]] = ...) -> None: ...

class PluginItem(_message.Message):
    __slots__ = ("name", "description", "version", "code", "timestamp")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    version: str
    code: str
    timestamp: int
    def __init__(
        self,
        name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        version: _Optional[str] = ...,
        code: _Optional[str] = ...,
        timestamp: _Optional[int] = ...,
    ) -> None: ...

class InstallRequest(_message.Message):
    __slots__ = ("owner", "version", "name", "description", "code", "extend")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    EXTEND_FIELD_NUMBER: _ClassVar[int]
    owner: str
    version: str
    name: str
    description: str
    code: str
    extend: str
    def __init__(
        self,
        owner: _Optional[str] = ...,
        version: _Optional[str] = ...,
        name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        code: _Optional[str] = ...,
        extend: _Optional[str] = ...,
    ) -> None: ...

class UninstallRequest(_message.Message):
    __slots__ = ("owner", "name")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    owner: str
    name: str
    def __init__(self, owner: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class UninstallResponse(_message.Message):
    __slots__ = ("responseStatus",)
    RESPONSESTATUS_FIELD_NUMBER: _ClassVar[int]
    responseStatus: _message_pb2.ResponseStatus
    def __init__(self, responseStatus: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class InstallResponse(_message.Message):
    __slots__ = ("responseStatus",)
    RESPONSESTATUS_FIELD_NUMBER: _ClassVar[int]
    responseStatus: _message_pb2.ResponseStatus
    def __init__(self, responseStatus: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/contract/contract.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/contract/contract.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"yeying/api/contract/contract.proto"\x16\n\x14\x43reateAddressRequest"(\n\x15\x43reateAddressResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t"I\n\x12TransactionRequest\x12\x11\n\ttoAddress\x18\x01 \x01(\t\x12\x0e\n\x06points\x18\x02 \x01(\x05\x12\x10\n\x08metadata\x18\x03 \x01(\t"-\n\x13TransactionResponse\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x03"!\n\x0e\x42\x61lanceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t"3\n\x0f\x42\x61lanceResponse\x12\r\n\x05total\x18\x01 \x01(\x03\x12\x11\n\tavailable\x18\x02 \x01(\x03"$\n\x11WalletInfoRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t"Z\n\x12WalletInfoResponse\x12\r\n\x05total\x18\x01 \x01(\x03\x12\x11\n\tavailable\x18\x02 \x01(\x03\x12"\n\x0ctransactions\x18\x03 \x03(\x0b\x32\x0c.Transaction"C\n\x0bTransaction\x12\x12\n\nto_address\x18\x01 \x01(\t\x12\x0e\n\x06points\x18\x02 \x01(\x05\x12\x10\n\x08metadata\x18\x03 \x01(\t2\xe7\x01\n\x06Wallet\x12>\n\rcreateAddress\x12\x15.CreateAddressRequest\x1a\x16.CreateAddressResponse\x12\x38\n\x0btransaction\x12\x13.TransactionRequest\x1a\x14.TransactionResponse\x12,\n\x07\x62\x61lance\x12\x0f.BalanceRequest\x1a\x10.BalanceResponse\x12\x35\n\nwalletInfo\x12\x12.WalletInfoRequest\x1a\x13.WalletInfoResponseb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.contract.contract_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_CREATEADDRESSREQUEST"]._serialized_start = 38
    _globals["_CREATEADDRESSREQUEST"]._serialized_end = 60
    _globals["_CREATEADDRESSRESPONSE"]._serialized_start = 62
    _globals["_CREATEADDRESSRESPONSE"]._serialized_end = 102
    _globals["_TRANSACTIONREQUEST"]._serialized_start = 104
    _globals["_TRANSACTIONREQUEST"]._serialized_end = 177
    _globals["_TRANSACTIONRESPONSE"]._serialized_start = 179
    _globals["_TRANSACTIONRESPONSE"]._serialized_end = 224
    _globals["_BALANCEREQUEST"]._serialized_start = 226
    _globals["_BALANCEREQUEST"]._serialized_end = 259
    _globals["_BALANCERESPONSE"]._serialized_start = 261
    _globals["_BALANCERESPONSE"]._serialized_end = 312
    _globals["_WALLETINFOREQUEST"]._serialized_start = 314
    _globals["_WALLETINFOREQUEST"]._serialized_end = 350
    _globals["_WALLETINFORESPONSE"]._serialized_start = 352
    _globals["_WALLETINFORESPONSE"]._serialized_end = 442
    _globals["_TRANSACTION"]._serialized_start = 444
    _globals["_TRANSACTION"]._serialized_end = 511
    _globals["_WALLET"]._serialized_start = 514
    _globals["_WALLET"]._serialized_end = 745
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/spider/spider.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/spider/spider.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eyeying/api/spider/spider.proto\x12\x11yeying.api.plugin\x1a\x1fyeying/api/common/message.proto"S\n\rSearchRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x33\n\rconditionList\x18\x02 \x03(\x0b\x32\x1c.yeying.api.plugin.Condition"\x18\n\tCondition\x12\x0b\n\x03sql\x18\x01 \x01(\t"G\n\x0eSearchResponse\x12\x35\n\x0epluginItemList\x18\x01 \x03(\x0b\x32\x1d.yeying.api.plugin.PluginItem"a\n\nPluginItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\x03"q\n\x0eInstallRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12\x0e\n\x06\x65xtend\x18\x06 \x01(\t"/\n\x10UninstallRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t"N\n\x11UninstallResponse\x12\x39\n\x0eresponseStatus\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"L\n\x0fInstallResponse\x12\x39\n\x0eresponseStatus\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus*!\n\nPluginType\x12\x07\n\x03WEB\x10\x00\x12\n\n\x06SPIDER\x10\x01\x32\xab\x03\n\x06Spider\x12O\n\x06Search\x12 .yeying.api.plugin.SearchRequest\x1a!.yeying.api.plugin.SearchResponse"\x00\x12R\n\x07Install\x12!.yeying.api.plugin.InstallRequest\x1a".yeying.api.plugin.InstallResponse"\x00\x12R\n\x07Upgrade\x12!.yeying.api.plugin.InstallRequest\x1a".yeying.api.plugin.InstallResponse"\x00\x12Q\n\x06\x43onfig\x12!.yeying.api.plugin.InstallRequest\x1a".yeying.api.plugin.InstallResponse"\x00\x12U\n\x06Remove\x12#.yeying.api.plugin.UninstallRequest\x1a$.yeying.api.plugin.UninstallResponse"\x00\x42\x13Z\x11yeying/api/pluginb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.spider.spider_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/plugin"
    _globals["_PLUGINTYPE"]._serialized_start = 691
    _globals["_PLUGINTYPE"]._serialized_end = 724
    _globals["_SEARCHREQUEST"]._serialized_start = 86
    _globals["_SEARCHREQUEST"]._serialized_end = 169
    _globals["_CONDITION"]._serialized_start = 171
    _globals["_CONDITION"]._serialized_end = 195
    _globals["_SEARCHRESPONSE"]._serialized_start = 197
    _globals["_SEARCHRESPONSE"]._serialized_end = 268
    _globals["_PLUGINITEM"]._serialized_start = 270
    _globals["_PLUGINITEM"]._serialized_end = 367
    _globals["_INSTALLREQUEST"]._serialized_start = 369
    _globals["_INSTALLREQUEST"]._serialized_end = 482
    _globals["_UNINSTALLREQUEST"]._serialized_start = 484
    _globals["_UNINSTALLREQUEST"]._serialized_end = 531
    _globals["_UNINSTALLRESPONSE"]._serialized_start = 533
    _globals["_UNINSTALLRESPONSE"]._serialized_end = 611
    _globals["_INSTALLRESPONSE"]._serialized_start = 613
    _globals["_INSTALLRESPONSE"]._serialized_end = 689
    _globals["_SPIDER"]._serialized_start = 727
    _globals["_SPIDER"]._serialized_end = 1154
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/application/application.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/application/application.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2
from yeying.api.common import model_pb2 as yeying_dot_api_dot_common_dot_model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(yeying/api/application/application.proto\x12\x16yeying.api.application\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto\x1a\x1dyeying/api/common/model.proto"\x90\x01\n\x18SearchApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.SearchApplicationRequestBody"\x88\x01\n\x1cSearchApplicationRequestBody\x12:\n\tcondition\x18\x01 \x01(\x0b\x32\'.yeying.api.application.SearchCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\xaf\x01\n\x0fSearchCondition\x12\x34\n\x04\x63ode\x18\x01 \x01(\x0e\x32&.yeying.api.common.ApplicationCodeEnum\x12\x38\n\x06status\x18\x02 \x01(\x0e\x32(.yeying.api.common.ApplicationStatusEnum\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07keyword\x18\x05 \x01(\t"\x92\x01\n\x19SearchApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.SearchApplicationResponseBody"\xbf\x01\n\x1dSearchApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12<\n\x0c\x61pplications\x18\x02 \x03(\x0b\x32&.yeying.api.common.ApplicationMetadata\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage"\x90\x01\n\x18\x43reateApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.CreateApplicationRequestBody"[\n\x1c\x43reateApplicationRequestBody\x12;\n\x0b\x61pplication\x18\x01 \x01(\x0b\x32&.yeying.api.common.ApplicationMetadata"\x92\x01\n\x19\x43reateApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.CreateApplicationResponseBody"\x8f\x01\n\x1d\x43reateApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12;\n\x0b\x61pplication\x18\x02 \x01(\x0b\x32&.yeying.api.common.ApplicationMetadata"\x90\x01\n\x18\x41pplicationDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.ApplicationDetailRequestBody"<\n\x1c\x41pplicationDetailRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x92\x01\n\x19\x41pplicationDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.ApplicationDetailResponseBody"\x8f\x01\n\x1d\x41pplicationDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12;\n\x0b\x61pplication\x18\x02 \x01(\x0b\x32&.yeying.api.common.ApplicationMetadata"\x92\x01\n\x19OfflineApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.OfflineApplicationRequestBody"=\n\x1dOfflineApplicationRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x94\x01\n\x1aOfflineApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.application.OfflineApplicationResponseBody"S\n\x1eOfflineApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x90\x01\n\x18OnlineApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.OnlineApplicationRequestBody"<\n\x1cOnlineApplicationRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x92\x01\n\x19OnlineApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.OnlineApplicationResponseBody"R\n\x1dOnlineApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"Q\n\x11\x41pplicationExtend\x12<\n\x08\x63omments\x18\x01 \x03(\x0b\x32*.yeying.api.application.ApplicationComment"Y\n\x12\x41pplicationComment\x12\x0f\n\x07\x61uditor\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\x12\x0e\n\x06passed\x18\x03 \x01(\x08\x12\x11\n\tsignature\x18\x04 \x01(\t"\x90\x01\n\x18\x44\x65leteApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.DeleteApplicationRequestBody"<\n\x1c\x44\x65leteApplicationRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x92\x01\n\x19\x44\x65leteApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.DeleteApplicationResponseBody"R\n\x1d\x44\x65leteApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x8e\x01\n\x17\x41uditApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.application.AuditApplicationRequestBody"x\n\x1b\x41uditApplicationRequestBody\x12;\n\x07\x63omment\x18\x01 \x01(\x0b\x32*.yeying.api.application.ApplicationComment\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\r"\x90\x01\n\x18\x41uditApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.AuditApplicationResponseBody"Q\n\x1c\x41uditApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xa4\x06\n\x0b\x41pplication\x12o\n\x06Search\x12\x30.yeying.api.application.SearchApplicationRequest\x1a\x31.yeying.api.application.SearchApplicationResponse"\x00\x12l\n\x05\x41udit\x12/.yeying.api.application.AuditApplicationRequest\x1a\x30.yeying.api.application.AuditApplicationResponse"\x00\x12o\n\x06\x43reate\x12\x30.yeying.api.application.CreateApplicationRequest\x1a\x31.yeying.api.application.CreateApplicationResponse"\x00\x12o\n\x06\x44\x65tail\x12\x30.yeying.api.application.ApplicationDetailRequest\x1a\x31.yeying.api.application.ApplicationDetailResponse"\x00\x12r\n\x07Offline\x12\x31.yeying.api.application.OfflineApplicationRequest\x1a\x32.yeying.api.application.OfflineApplicationResponse"\x00\x12o\n\x06Online\x12\x30.yeying.api.application.OnlineApplicationRequest\x1a\x31.yeying.api.application.OnlineApplicationResponse"\x00\x12o\n\x06\x44\x65lete\x12\x30.yeying.api.application.DeleteApplicationRequest\x1a\x31.yeying.api.application.DeleteApplicationResponse"\x00\x42\x18Z\x16yeying/api/applicationb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.application.application_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\026yeying/api/application"
    _globals["_SEARCHAPPLICATIONREQUEST"]._serialized_start = 163
    _globals["_SEARCHAPPLICATIONREQUEST"]._serialized_end = 307
    _globals["_SEARCHAPPLICATIONREQUESTBODY"]._serialized_start = 310
    _globals["_SEARCHAPPLICATIONREQUESTBODY"]._serialized_end = 446
    _globals["_SEARCHCONDITION"]._serialized_start = 449
    _globals["_SEARCHCONDITION"]._serialized_end = 624
    _globals["_SEARCHAPPLICATIONRESPONSE"]._serialized_start = 627
    _globals["_SEARCHAPPLICATIONRESPONSE"]._serialized_end = 773
    _globals["_SEARCHAPPLICATIONRESPONSEBODY"]._serialized_start = 776
    _globals["_SEARCHAPPLICATIONRESPONSEBODY"]._serialized_end = 967
    _globals["_CREATEAPPLICATIONREQUEST"]._serialized_start = 970
    _globals["_CREATEAPPLICATIONREQUEST"]._serialized_end = 1114
    _globals["_CREATEAPPLICATIONREQUESTBODY"]._serialized_start = 1116
    _globals["_CREATEAPPLICATIONREQUESTBODY"]._serialized_end = 1207
    _globals["_CREATEAPPLICATIONRESPONSE"]._serialized_start = 1210
    _globals["_CREATEAPPLICATIONRESPONSE"]._serialized_end = 1356
    _globals["_CREATEAPPLICATIONRESPONSEBODY"]._serialized_start = 1359
    _globals["_CREATEAPPLICATIONRESPONSEBODY"]._serialized_end = 1502
    _globals["_APPLICATIONDETAILREQUEST"]._serialized_start = 1505
    _globals["_APPLICATIONDETAILREQUEST"]._serialized_end = 1649
    _globals["_APPLICATIONDETAILREQUESTBODY"]._serialized_start = 1651
    _globals["_APPLICATIONDETAILREQUESTBODY"]._serialized_end = 1711
    _globals["_APPLICATIONDETAILRESPONSE"]._serialized_start = 1714
    _globals["_APPLICATIONDETAILRESPONSE"]._serialized_end = 1860
    _globals["_APPLICATIONDETAILRESPONSEBODY"]._serialized_start = 1863
    _globals["_APPLICATIONDETAILRESPONSEBODY"]._serialized_end = 2006
    _globals["_OFFLINEAPPLICATIONREQUEST"]._serialized_start = 2009
    _globals["_OFFLINEAPPLICATIONREQUEST"]._serialized_end = 2155
    _globals["_OFFLINEAPPLICATIONREQUESTBODY"]._serialized_start = 2157
    _globals["_OFFLINEAPPLICATIONREQUESTBODY"]._serialized_end = 2218
    _globals["_OFFLINEAPPLICATIONRESPONSE"]._serialized_start = 2221
    _globals["_OFFLINEAPPLICATIONRESPONSE"]._serialized_end = 2369
    _globals["_OFFLINEAPPLICATIONRESPONSEBODY"]._serialized_start = 2371
    _globals["_OFFLINEAPPLICATIONRESPONSEBODY"]._serialized_end = 2454
    _globals["_ONLINEAPPLICATIONREQUEST"]._serialized_start = 2457
    _globals["_ONLINEAPPLICATIONREQUEST"]._serialized_end = 2601
    _globals["_ONLINEAPPLICATIONREQUESTBODY"]._serialized_start = 2603
    _globals["_ONLINEAPPLICATIONREQUESTBODY"]._serialized_end = 2663
    _globals["_ONLINEAPPLICATIONRESPONSE"]._serialized_start = 2666
    _globals["_ONLINEAPPLICATIONRESPONSE"]._serialized_end = 2812
    _globals["_ONLINEAPPLICATIONRESPONSEBODY"]._serialized_start = 2814
    _globals["_ONLINEAPPLICATIONRESPONSEBODY"]._serialized_end = 2896
    _globals["_APPLICATIONEXTEND"]._serialized_start = 2898
    _globals["_APPLICATIONEXTEND"]._serialized_end = 2979
    _globals["_APPLICATIONCOMMENT"]._serialized_start = 2981
    _globals["_APPLICATIONCOMMENT"]._serialized_end = 3070
    _globals["_DELETEAPPLICATIONREQUEST"]._serialized_start = 3073
    _globals["_DELETEAPPLICATIONREQUEST"]._serialized_end = 3217
    _globals["_DELETEAPPLICATIONREQUESTBODY"]._serialized_start = 3219
    _globals["_DELETEAPPLICATIONREQUESTBODY"]._serialized_end = 3279
    _globals["_DELETEAPPLICATIONRESPONSE"]._serialized_start = 3282
    _globals["_DELETEAPPLICATIONRESPONSE"]._serialized_end = 3428
    _globals["_DELETEAPPLICATIONRESPONSEBODY"]._serialized_start = 3430
    _globals["_DELETEAPPLICATIONRESPONSEBODY"]._serialized_end = 3512
    _globals["_AUDITAPPLICATIONREQUEST"]._serialized_start = 3515
    _globals["_AUDITAPPLICATIONREQUEST"]._serialized_end = 3657
    _globals["_AUDITAPPLICATIONREQUESTBODY"]._serialized_start = 3659
    _globals["_AUDITAPPLICATIONREQUESTBODY"]._serialized_end = 3779
    _globals["_AUDITAPPLICATIONRESPONSE"]._serialized_start = 3782
    _globals["_AUDITAPPLICATIONRESPONSE"]._serialized_end = 3926
    _globals["_AUDITAPPLICATIONRESPONSEBODY"]._serialized_start = 3928
    _globals["_AUDITAPPLICATIONRESPONSEBODY"]._serialized_end = 4009
    _globals["_APPLICATION"]._serialized_start = 4012
    _globals["_APPLICATION"]._serialized_end = 4816
# @@protoc_insertion_point(module_scope)



from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as _meta_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class AddTaskTagRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddTaskTagRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AddTaskTagRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AddTaskTagRequestBody(_message.Message):
    __slots__ = ("meta",)
    META_FIELD_NUMBER: _ClassVar[int]
    meta: _meta_pb2.TaskTagMetadata
    def __init__(self, meta: _Optional[_Union[_meta_pb2.TaskTagMetadata, _Mapping]] = ...) -> None: ...

class AddTaskTagResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddTaskTagResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AddTaskTagResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AddTaskTagResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.TaskTagMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.TaskTagMetadata, _Mapping]] = ...,
    ) -> None: ...

class DetailTaskTagRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DetailTaskTagRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DetailTaskTagRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DetailTaskTagRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class DetailTaskTagResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DetailTaskTagResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DetailTaskTagResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DetailTaskTagResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.TaskTagMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.TaskTagMetadata, _Mapping]] = ...,
    ) -> None: ...

class ListTaskTagRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ListTaskTagRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ListTaskTagRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ListTaskTagRequestBody(_message.Message):
    __slots__ = ("did",)
    DID_FIELD_NUMBER: _ClassVar[int]
    did: str
    def __init__(self, did: _Optional[str] = ...) -> None: ...

class ListTaskTagResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ListTaskTagResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ListTaskTagResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ListTaskTagResponseBody(_message.Message):
    __slots__ = ("status", "list")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    LIST_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    list: _containers.RepeatedCompositeFieldContainer[_meta_pb2.TaskTagMetadata]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        list: _Optional[_Iterable[_Union[_meta_pb2.TaskTagMetadata, _Mapping]]] = ...,
    ) -> None: ...

class UpdateTaskTagRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateTaskTagRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateTaskTagRequestBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateTaskTagRequestBody(_message.Message):
    __slots__ = ("meta",)
    META_FIELD_NUMBER: _ClassVar[int]
    meta: _meta_pb2.TaskTagMetadata
    def __init__(self, meta: _Optional[_Union[_meta_pb2.TaskTagMetadata, _Mapping]] = ...) -> None: ...

class UpdateTaskTagResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateTaskTagResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateTaskTagResponseBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateTaskTagResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.TaskTagMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.TaskTagMetadata, _Mapping]] = ...,
    ) -> None: ...

class DeleteTaskTagRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteTaskTagRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteTaskTagRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteTaskTagRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class DeleteTaskTagResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteTaskTagResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteTaskTagResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteTaskTagResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.TaskTagMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.TaskTagMetadata, _Mapping]] = ...,
    ) -> None: ...



# Generated by protobuf_init. Do not edit manually.
from .mail_pb2 import SendMailRequest
from .mail_pb2 import SendMailRequestBody
from .mail_pb2 import SendMailResponse
from .mail_pb2 import SendMailResponseBody
from .mail_pb2 import VerifyMailRequest
from .mail_pb2 import VerifyMailRequestBody
from .mail_pb2 import VerifyMailResponse
from .mail_pb2 import VerifyMailResponseBody
from .mail_pb2_grpc import MailServicer
from .mail_pb2_grpc import MailStub
from .mail_pb2_grpc import add_MailServicer_to_server
from .mail_pb2_grpc import Mail



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.apps.zuoyepigai import warehouse_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2

GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/apps/zuoyepigai/warehouse_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class WarehouseStub(object):
    """*
    资产仓库管理
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Add = channel.unary_unary(
            "/yeying.api.apps.zuoyepigai.Warehouse/Add",
            request_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.AddWarehouseRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.AddWarehouseResponse.FromString,
            _registered_method=True,
        )
        self.List = channel.unary_unary(
            "/yeying.api.apps.zuoyepigai.Warehouse/List",
            request_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.ListWarehouseRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.ListWarehouseResponse.FromString,
            _registered_method=True,
        )
        self.Detail = channel.unary_unary(
            "/yeying.api.apps.zuoyepigai.Warehouse/Detail",
            request_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.DetailWarehouseRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.DetailWarehouseResponse.FromString,
            _registered_method=True,
        )


class WarehouseServicer(object):
    """*
    资产仓库管理
    """

    def Add(self, request, context):
        """*
        资产上传：例如上传试卷：
        1: 上传空白试卷
        2: 上传空白试卷 + 对应的答案
        3: 上传已作答的试卷
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def List(self, request, context):
        """*
        资产列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Detail(self, request, context):
        """*
        资产列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_WarehouseServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Add": grpc.unary_unary_rpc_method_handler(
            servicer.Add,
            request_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.AddWarehouseRequest.FromString,
            response_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.AddWarehouseResponse.SerializeToString,
        ),
        "List": grpc.unary_unary_rpc_method_handler(
            servicer.List,
            request_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.ListWarehouseRequest.FromString,
            response_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.ListWarehouseResponse.SerializeToString,
        ),
        "Detail": grpc.unary_unary_rpc_method_handler(
            servicer.Detail,
            request_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.DetailWarehouseRequest.FromString,
            response_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.DetailWarehouseResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("yeying.api.apps.zuoyepigai.Warehouse", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("yeying.api.apps.zuoyepigai.Warehouse", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Warehouse(object):
    """*
    资产仓库管理
    """

    @staticmethod
    def Add(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.apps.zuoyepigai.Warehouse/Add",
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.AddWarehouseRequest.SerializeToString,
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.AddWarehouseResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def List(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.apps.zuoyepigai.Warehouse/List",
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.ListWarehouseRequest.SerializeToString,
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.ListWarehouseResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Detail(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.apps.zuoyepigai.Warehouse/Detail",
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.DetailWarehouseRequest.SerializeToString,
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_warehouse__pb2.DetailWarehouseResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Generated by protobuf_init. Do not edit manually.
from .code_pb2 import ResponseCodeEnum
from .code_pb2 import ContractStatusEnum
from .code_pb2 import LanguageCodeEnum
from .code_pb2 import ApplicationCodeEnum
from .code_pb2 import ServiceCodeEnum
from .code_pb2 import ApiCodeEnum
from .code_pb2 import ImageFormatEnum
from .code_pb2 import DigitalFormatEnum
from .code_pb2 import ContentFormatEnum
from .code_pb2 import SessionSceneEnum
from .code_pb2 import SessionRoleEnum
from .code_pb2 import ParticipantTypeEnum
from .code_pb2 import AuditTypeEnum
from .code_pb2 import ApplicationStatusEnum
from .code_pb2 import CipherTypeEnum
from .code_pb2 import AuthenticateTypeEnum
from .message_pb2 import MessageHeader
from .message_pb2 import ResponseStatus
from .message_pb2 import ResponsePage
from .message_pb2 import RequestPage
from .model_pb2 import ApplicationMetadata
from .model_pb2 import ServiceMetadata
from .model_pb2 import StateMetadata
